.. _core_device_overview:

Overview
--------

The following sections describe the parts of the Device plugin.

Enrolment
`````````

The device plugin provides enrollment for user devices or browsers connecting to
the Peek client service.

If a device is not enrolled, the device will not be able to access the Peek
Services.

Online Status
`````````````

The device plugin provides the online/offline status of the users devices.

This can be used with integrations to other systems when Peek is used for mobility.
